@@ -332,8 +332,8 @@ void BrowserApplication::loadSettings()
         proxy.setPort(settings.value(QLatin1String("port"), 1080).toInt());
         proxy.setUser(settings.value(QLatin1String("userName")).toString());
         proxy.setPassword(settings.value(QLatin1String("password")).toString());
+        QNetworkProxy::setApplicationProxy(proxy);
     }
-    QNetworkProxy::setApplicationProxy(proxy);
     settings.endGroup();
 }
 
@@ -577,7 +577,7 @@ void BrowserApplication::setPrivateBrowsing(bool privateBrowsing)
     } else {
         Q_FOREACH (BrowserMainWindow* window, mainWindows()) {
             window->tabWidget()->setProfile(QWebEngineProfile::defaultProfile());
-            window->m_lastSearch = QString::null;
+            window->m_lastSearch = QString();
             window->tabWidget()->clear();
         }
     }
